#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.


from psym.client import SymphonyClient
from psym.common.data_class import Kpi, domain, KpiCategory

from ..graphql.input.edit_kpi_input import EditKpiInput
from ..graphql.input.add_kpi_input import AddKpiInput
from ..graphql.mutation.add_kpi import addKpi
from ..graphql.mutation.edit_kpi import editKpi
from ..graphql.mutation.remove_kpi import removeKpi
from ..graphql.query.kpis import kpis
from psym.common.constant import PAGINATION_STEP
from typing import Any, Dict, Iterator, List, Optional




def add_kpi(
    client: SymphonyClient, name: str, description: str, status: bool, domainId: str, kpiCategoryId: str
) -> domain:
   
    domain_input = AddKpiInput(name=name, description=description,
    status=status, 
    domainFk=domainId,
    kpiCategoryFK=kpiCategoryId)

    result = addKpi.execute(client, input=domain_input)

    return Kpi(name=result.name, id=result.id, 
    description=result.description, 
    status=result.status, 
    domainFK=result.domainFk, 
    kpiCategoryFK=result.kpiCategoryFK)

def edit_kpi(
    client: SymphonyClient,
    KPI: Kpi,
    new_name: Optional[str] = None,
    description: str = None,
    status: bool = None,
    domainId: domain = None,
    kpiCategoryId: KpiCategory = None,
) -> None:
    params: Dict[str, Any] = {}
    if new_name is not None:
        params.update({"_name_": new_name})
    if new_name is not None:
        editKpi.execute(client, input=EditKpiInput(id=KPI.id, 
        name=new_name,
        description=description,
        status= status,
        domainFk=domainId,
        kpiCategoryFK=kpiCategoryId
        ))










#!/usr/bin/env python3
# @generated AUTOGENERATED file. Do not Change!

from dataclasses import dataclass, field as _field
from ...config import custom_scalars, datetime
from gql_client.runtime.variables import encode_variables
from gql import gql, Client
from gql.transport.exceptions import TransportQueryError
from functools import partial
from numbers import Number
from typing import Any, AsyncGenerator, Dict, List, Generator, Optional
from time import perf_counter
from dataclasses_json import DataClassJsonMixin, config

from ..input.add_counter_input import AddCounterInput


# fmt: off
QUERY: List[str] = ["""
mutation addCounter($input: AddCounterInput!) {
  addCounter(input: $input) {
    id
    name
    externalID
    counterFamily{id}
    vendorFk{id}
    networkManagerSystem
  }
}


"""
]


class addCounter:
    @dataclass(frozen=True)
    class addCounterData(DataClassJsonMixin):
        @dataclass(frozen=True)
        class Counter(DataClassJsonMixin):
            @dataclass(frozen=True)
            class CounterFamily(DataClassJsonMixin):
                id: str

            @dataclass(frozen=True)
            class Vendor(DataClassJsonMixin):
                id: str

            id: str
            name: str
            externalID: str
            counterFamily: Optional[CounterFamily]
            vendorFk: Vendor
            networkManagerSystem: str

        addCounter: Counter

    # fmt: off
    @classmethod
    def execute(cls, client: Client, input: AddCounterInput) -> addCounterData.Counter:
        variables: Dict[str, Any] = {"input": input}
        new_variables = encode_variables(variables, custom_scalars)
        response_text = client.execute(
            gql("".join(set(QUERY))), variable_values=new_variables
        )
        res = cls.addCounterData.from_dict(response_text)
        return res.addCounter

    # fmt: off
    @classmethod
    async def execute_async(cls, client: Client, input: AddCounterInput) -> addCounterData.Counter:
        variables: Dict[str, Any] = {"input": input}
        new_variables = encode_variables(variables, custom_scalars)
        response_text = await client.execute_async(
            gql("".join(set(QUERY))), variable_values=new_variables
        )
        res = cls.addCounterData.from_dict(response_text)
        return res.addCounter
